import datetime as dt

import pytest

from aiostp.utils import get_file_body, strftime, strptime


def test_strftime():
    assert strftime(dt.date(2020, 4, 20)) == '20200420'


def test_strptime():
    assert strptime('20200420') == dt.date(2020, 4, 20)


@pytest.mark.asyncio
async def test_get_file_body_file():
    res = await get_file_body('tests/data/test.txt')
    assert res == b'hello world'


@pytest.mark.asyncio
async def test_get_file_body_bytes():
    res = await get_file_body(b'hello world')
    assert res == b'hello world'



from typing import Union

from cryptography.exceptions import UnsupportedAlgorithm
from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives import serialization
from stpmex.exc import InvalidPassphrase

from .utils import get_file_body


async def gen_pkey(priv_key: Union[str, bytes], priv_key_passphrase: str):
    if not priv_key:
        return None
    pkey = await get_file_body(priv_key)

    try:
        return serialization.load_pem_private_key(
            pkey, priv_key_passphrase.encode('ascii'), default_backend()
        )
    except (ValueError, TypeError, UnsupportedAlgorithm):
        raise InvalidPassphrase
